"""
*Tools used to perform download of files and HTML pages from the web*
"""

from _fetch import _fetch
from _dump_files_to_local_drive import _dump_files_to_local_drive
from get_now_datetime_filestamp import get_now_datetime_filestamp
from extract_filename_from_url import extract_filename_from_url
from append_now_datestamp_to_filename import append_now_datestamp_to_filename
from multiobject_download import multiobject_download
